aboutsummaryrefslogtreecommitdiff
path: root/engines/glk/frotz/frotz.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/glk/frotz/frotz.h')
-rw-r--r--engines/glk/frotz/frotz.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/glk/frotz/frotz.h b/engines/glk/frotz/frotz.h
index c1fe5dcab6..cecd88637a 100644
--- a/engines/glk/frotz/frotz.h
+++ b/engines/glk/frotz/frotz.h
@@ -25,7 +25,7 @@
#include "glk/frotz/processor.h"
-namespace Gargoyle {
+namespace Glk {
namespace Frotz {
/**
@@ -36,7 +36,7 @@ public:
/**
* Constructor
*/
- Frotz(OSystem *syst, const GargoyleGameDescription *gameDesc);
+ Frotz(OSystem *syst, const GlkGameDescription *gameDesc);
/**
* Destructor
@@ -67,6 +67,6 @@ public:
extern Frotz *g_vm;
} // End of namespace Frotz
-} // End of namespace Gargoyle
+} // End of namespace Glk
#endif